==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/ru/api.php <==
<?php
regGS("Cannot create file \"$1\"", "Невозможно создать файл \"$1\"");
regGS("The IP address group $1 has been deleted.", "Группа IP-адресов $1 была удалена.");
regGS("IP Group $1 added for user $2", "Группа IP-адресов $1добавлена для пользователя $2");
regGS("User permissions for $1 changed", "Пользовательские права для $1 изменены");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Секция $1 удалена. (Выпуск: $2, Публикация: $3 )");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Секция $1 добавлена. (Выпуск: $2, Публикация: $3 )");
regGS("Issue $1 changed status to $2", "Выпуск $1 изменил состояние на $2");
regGS("User type $1 deleted", "Пользовательский тип $1 удален");
regGS("User type $1 added", "Пользовательский тип $1 добавлен");
regGS("Topic $1 added to article", "Статья $1 добавлена к статье");
regGS("Last", "Последний");
regGS("First", "Первый");
regGS("Changed image properties of $1", "Измененные свойства картинки $1");
regGS("Article topic $1 deleted", "Удалена тема статьи $1");
regGS("Article #$1 \"$2\" ($3) created.", "Статья #$1 \"$2\" ($3) создана.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Статья #$1 \"$2\" ($3) переведена на \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Статья #$1 \"$2\" ($3)скопирована в статью #$3.");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Статья #$1: Состояние \"$2\" изменено из $3 в $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Статья #$1: \"$2\" ($3) удалена.");
regGS("Text", "Текст");
regGS("Article body", "Тело статьи");
regGS("The default subscription time for $1 has been added.", "Время подписки по умолчанию для $1 успешно добавлено.");
regGS("Image $1 linked to article $2", "Картинки $1 привязана к статье $2");
regGS("Image $1 unlinked from $2", "Картинка $1 отвязана от $2");
regGS("The image $1 has been added.", "Картинка $1 была успешно добавлена.");
regGS("Image $1 deleted", "Удалена картинка $1");
regGS("Publication $1 changed", "Публикация $1 изменена");
regGS("Publication $1 deleted", "Публикация $1 удалена");
regGS("Publication $1 added", "Добавлен публикация $1");
regGS("Issue $1 from publication $2 deleted", "Удален выпуск $1 из публикации $2");
regGS("Issue $1 added in publication $2", "Выпуск $1 добавлен в публикацию $2");
regGS("The article type $1 has been deleted.", "Тип статей $1 был удален");
regGS("The article type $1 has been added.", "Тип статьи $1 был добавлен.");
regGS("Article type field $1 created", "Создан тип статей $1");
regGS("Article type field $1 deleted", "Удалено поле типов статей $1");
regGS("Language $1 added", "Язык $1 добавлен");
regGS("Language $1 deleted", "Удален язык $1");
regGS("Language $1 modified", "Язык $1 обновлен");
regGS("Country $1 added", "Страна $1 добавлена");
regGS("Country $1 deleted", "Страна $1 удалена");
regGS("Country name $1 changed", "Изменено название страны $1");
regGS("The user account $1 has been deleted.", "Учетная запись пользователя $1 удалена.");
regGS("Password changed for $1", "Изменен пароль для $1");
regGS("User account $1 created", "Создана учетная запись пользователя $1");
regGS("Template $1 uploaded", "Загружен шаблон $1");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/ru/api.php <==
<?php 
regGS("Template $1 no longer exists!", "");
regGS("The file uploaded is not an image.", "Загруженный файл не является картинкой.");
regGS("Field $1 updated", "Поле $1 обновлено");
regGS("Could not delete record from the database.", "Не удалось удалить запись из базы данных.");
regGS("template path", "путь к шаблону");
regGS("short names", "короткие имена");
regGS("Unable to fetch image from remote server.", "Невозможно извлечь картинку с удаленного сервера.");
regGS("The article type field $1 has been renamed to $2.", "Поле $1 типа статьи переименовано в $2.");
regGS("The article type $1 has been renamed to $2.", "Типа статьи $1 переименован в $2.");
regGS("Article type field $1 changed", "Изменено поле $1 типа статьи");
regGS("Article Type $1 translation updated", "Обновлен перевод типа статьи $1");
regGS("The IP address group $1 has been deleted.", "Группа IP-адресов $1 была удалена.");
regGS("IP Group $1 added for user $2", "Группа IP-адресов $1добавлена для пользователя $2");
regGS("User permissions for $1 changed", "Пользовательские права для $1 изменены");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Секция $1 удалена. (Выпуск: $2, Публикация: $3 )");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Секция $1 добавлена. (Выпуск: $2, Публикация: $3 )");
regGS("Issue $1 changed status to $2", "Выпуск $1 изменил состояние на $2");
regGS("User type $1 deleted", "Пользовательский тип $1 удален");
regGS("User type $1 added", "Пользовательский тип $1 добавлен");
regGS("Topic $1 added to article", "Статья $1 добавлена к статье");
regGS("Last", "Последний");
regGS("First", "Первый");
regGS("Changed image properties of $1", "Измененные свойства картинки $1");
regGS("Article topic $1 deleted", "Удалена тема статьи $1");
regGS("Article #$1 \"$2\" ($3) created.", "Статья #$1 \"$2\" ($3) создана.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Статья #$1 \"$2\" ($3) переведена на \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Статья #$1 \"$2\" ($3)скопирована в статью #$3.");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Статья #$1: Состояние \"$2\" изменено из $3 в $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Статья #$1: \"$2\" ($3) удалена.");
regGS("Single-line Text", "Текст");
regGS("Multi-line Text with WYSIWYG", "Тело статьи");
regGS("The default subscription time for $1 has been added.", "Время подписки по умолчанию для $1 успешно добавлено.");
regGS("Image $1 linked to article $2", "Картинки $1 привязана к статье $2");
regGS("Image $1 unlinked from $2", "Картинка $1 отвязана от $2");
regGS("The image $1 has been added.", "Картинка $1 была успешно добавлена.");
regGS("Image $1 deleted", "Удалена картинка $1");
regGS("Publication $1 changed", "Публикация $1 изменена");
regGS("Publication $1 deleted", "Публикация $1 удалена");
regGS("Publication $1 added", "Добавлен публикация $1");
regGS("Issue $1 from publication $2 deleted", "Удален выпуск $1 из публикации $2");
regGS("Issue $1 added in publication $2", "Выпуск $1 добавлен в публикацию $2");
regGS("The article type $1 has been deleted.", "Тип статей $1 был удален");
regGS("The article type $1 has been added.", "Тип статьи $1 был добавлен.");
regGS("Article type field $1 created", "Создан тип статей $1");
regGS("Article type field $1 deleted", "Удалено поле типов статей $1");
regGS("Language $1 added", "Язык $1 добавлен");
regGS("Language $1 deleted", "Удален язык $1");
regGS("Language $1 modified", "Язык $1 обновлен");
regGS("Country $1 added", "Страна $1 добавлена");
regGS("Country $1 deleted", "Страна $1 удалена");
regGS("Country name $1 changed", "Изменено название страны $1");
regGS("The user account $1 has been deleted.", "Учетная запись пользователя $1 удалена.");
regGS("Password changed for $1", "Изменен пароль для $1");
regGS("User account $1 created", "Создана учетная запись пользователя $1");
regGS("Template $1 uploaded", "Загружен шаблон $1");
regGS("URL \"$1\" is invalid or is not an image.", "URL \"$1\" неверен или не является картинкой");
regGS("URL \"$1\" is not an image.", "URL \"$1\" не является картинкой");
regGS("Topic $1 added", "Добавлена тема $1");
regGS("Topic $1 deleted", "Удалена тема $1");
regGS("Topic $1 updated", "Тема $1 обновлена");
?>
